@@ -6,6 +6,7 @@
 
 
 #include "re_thread.h"
+#include "re_atomic.h"
 
 /**
  * Defines the timeout handler
@@ -19,7 +20,8 @@ struct tmrl;
 /** Defines a timer */
 struct tmr {
 	struct le le;       /**< Linked list element */
-	mtx_t *lock;        /**< Mutex lock          */
+	RE_ATOMIC bool active; /**< Timer is active  */
+	mtx_t *llock;       /**< List Mutex lock     */
 	tmr_h *th;          /**< Timeout handler     */
 	void *arg;          /**< Handler argument    */
 	uint64_t jfs;       /**< Jiffies for timeout */
